//
// This code is part of https://demo.grapecity.com.cn/gcword.
// Copyright (c) MESCIUS inc. All rights reserved.
//
using System;
using System.IO;
using System.Drawing;
using System.Collections.Generic;
using System.Linq;
using System.Globalization;
using GrapeCity.Documents.Word;

namespace DsWordWeb.Demos
{
    // This example shows how to use the todouble() template formatter
    // to enable using numeric format specifiers (percent in this sample)
    // on numeric values stored as strings in the data source.
    public class DataTplToDouble
    {
        public GcWordDocument CreateDocx()
        {
            // The data source (ocean and sea data from Wikipedia),
            // note that in order to demonstrate the todouble() formatter,
            // the 'areaOfWorldOcean' in this data source is a string rather
            // than a number:
            var oceans = new[]
            {
                new { name = "Pacific", areaOfWorldOcean = "0.466", volumeOfWorldOcean = 0.501, seas = new[]
                    { new {name = "Australasian Mediterranean Sea" }, new { name = "Philippine Sea" }, new { name = "Coral Sea" }, new { name = "South China Sea"}  }
                },
                new { name = "Atlantic", areaOfWorldOcean = "0.235", volumeOfWorldOcean = 0.233, seas = new[]
                    { new {name = "Sargasso Sea" }, new { name = "Caribbean Sea" }, new { name = "Mediterranean Sea" }, new { name = "Gulf of Guinea" } }
                },
                new { name = "Indian", areaOfWorldOcean = "0.195", volumeOfWorldOcean = 0.198, seas = new[]
                    { new {name = "Arabian Sea" }, new { name = "Bay of Bengal" }, new { name = "Andaman Sea" }, new { name = "Laccadive Sea" } }
                },
                new { name = "Southern", areaOfWorldOcean = "0.061", volumeOfWorldOcean = 0.054, seas = new[]
                    { new {name = "Weddell Sea" }, new { name = "Somov Sea" }, new { name = "Riiser-Larsen Sea" }, new { name = "Lazarev Sea" } }
                },
                new { name = "Arctic", areaOfWorldOcean = "0.043", volumeOfWorldOcean = 0.014, seas = new[]
                    { new {name = "Barents Sea" }, new { name = "Greenland Sea" }, new { name = "East Siberian Sea" }, new { name = "Kara Sea" } }
                },
            };

            var doc = new GcWordDocument();

            // Add the data source to the data template data sources:
            doc.DataTemplate.DataSources.Add("ds", oceans);

            // Add list templates for the two-level list:
            var listTplTop = doc.ListTemplates.Add(BuiltInListTemplateId.NumberArabicParenthesis, "listTplTop");
            var listTplNested = doc.ListTemplates.Add(BuiltInListTemplateId.BulletDefault, "listTplNested");

            // 'areaOfWorldOcean' in the data source is a string, so in order to be able
            // to use percent formatting on it we convert it to a number using the
            // todouble() formatter, then pass the result to format():
            var p1 = doc.Body.Paragraphs.Add("{{#ds}}{{name}} - {{areaOfWorldOcean}:todouble():format(0.#%)} of World Ocean area:");
            p1.ListFormat.Template = listTplTop;
            // Print the ocean's largest sea names as the nested list:
            var p2 = doc.Body.Paragraphs.Add("{{seas.name}}{{/ds}}");
            p2.ListFormat.Template = listTplNested;
            p2.ListFormat.LevelNumber = 1;

            // Note that we explicitly specify the culture to make sure that
            // the dot in 'areaOfWorldOcean' strings is recognized as decimal separator:
            doc.DataTemplate.Process(CultureInfo.GetCultureInfo("en-US"));

            // Done:
            return doc;
        }
    }
}
